@@ -5,8 +5,10 @@ pub const TIME_INVALIDATOR_SIZE: usize = 8 + std::mem::size_of::<TimeInvalidator
 #[account]
 pub struct TimeInvalidator {
     pub bump: u8,
-    pub expiration: Option<i64>,
     pub token_manager: Pubkey,
+    pub payment_manager: Pubkey,
+    pub collector: Pubkey,
+    pub expiration: Option<i64>,
     pub duration_seconds: Option<i64>,
     pub extension_payment_amount: Option<u64>,
     pub extension_duration_seconds: Option<u64>,
